@@ -125,8 +125,11 @@
 #ifndef SERIO_PSMULT
 # define SERIO_PS2MULT		0x3c
 #endif
+#ifndef SERIO_WACOM_IV
+# define SERIO_WACOM_IV		0x3e
+#endif
 #ifndef SERIO_EASYPEN
-# define SERIO_EASYPEN		0x3e
+# define SERIO_EASYPEN		0x3f
 #endif
 
 #endif
